@@ -17,10 +17,23 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
-from .package_info import __version__
+from .__about__ import __version__, __authors__
 import os
-# Ensure all file_formats are registered with Arcana
-from .file_format import registered_file_formats
 
 # Should be set explicitly in all FSL interfaces, but this squashes the warning
 os.environ['FSLOUTPUTTYPE'] = 'NIFTI_GZ'
+
+# Import all objects from Arcana used to design and apply Banana studies
+from arcana import (  # @IgnorePep8
+    SubStudySpec, Parameter, ParamSpec, SwitchSpec, FileFormat, Fileset,
+    FilesetSpec, FilesetInput, FilesetInputSpec, FilesetCollection, Field,
+    FieldSpec, FieldInput, FieldInputSpec, FieldCollection, SingleProc,
+    MultiProc, SlurmProc, DEFAULT_PROV_CHECK, DEFAULT_PROV_IGNORE, StaticEnv,
+    ModulesEnv, BasicRepo, XnatRepo)
+
+from .bids import BidsRepo  # @IgnorePep8
+
+
+# Import all Study classes into package root
+# from .study.base import (  # @IgnorePep8
+#     Study, StudyMetaClass, MultiStudy, MultiStudyMetaClass)
