@@ -1,8 +1,9 @@
 from .base import MriStudy
-from .diffusion import DiffusionStudy
+from .dwi import DwiStudy
+from .fmri import FmriStudy
 from .t1 import T1Study
 from .t2 import T2Study
-from .t2star import T2StarStudy
+from .t2star import T2starStudy
 # from .fmri import FmriStudy
 # from .ute import Utetudy
 from .epi import EpiStudy
